#
# spec file for package btop
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           btop
Version:        1.2.13+git20230615.7e50b03
Release:        1.1
Summary:        Usage and stats for processor, memory, disks, network and processes
License:        Apache-2.0
Group:          System/Monitoring
URL:            https://github.com/aristocratos/btop
Source:         %{name}-%{version}.tar.gz
BuildRequires:  coreutils
%if 0%{?suse_version} < 1550
%define cxxopt CXX=g++-10
BuildRequires:  gcc10-c++
%else
%define cxxopt %{nil}
BuildRequires:  gcc-c++ >= 11
%endif
BuildRequires:  sed

%description
Resource monitor that shows usage and stats for processor, memory, disks, network and processes. C++ version and continuation of bashtop and bpytop.

%prep
%setup -q

%build
%make_build %{cxxopt}

%install
%make_install PREFIX=/usr

%files
%{_bindir}/btop
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/themes
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/48x48
%dir %{_datadir}/icons/hicolor/48x48/apps
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/%{name}/README.md
%{_datadir}/%{name}/themes/*.theme
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%license LICENSE
%doc CHANGELOG.md

%changelog
* Fri Jun 23 2023 scott.bradnick@suse.com
- Update to version 1.2.13+git20230615.7e50b03:
  * Fix integer overflows in btop_collect.cpp
  * Enable Clang as a compiler.
  * Remove pthread_exit().
  * Replace `statvfs64` with `statvfs` and define `_FILE_OFFSET_BITS=64`.
  * Include <codecvt> required by Clang.
  * Move `#include` to top level and exclude Clang from compiler version check.
  * Insert `std::` for warning `unqualified call to std::move`.
  * Include 3rd party headers with isystem to silence warnings.
  * amend! update cpu load average display
  * update cpu load average display
  * chore: remove spaces before language in code blocks
  * chore: update readme to include --recursive
  * chore: adjust worflows to recursively clone the repository
  * feat: prefer fmt submodule over copy-and-paste headers
  * println -> fmt::println
  * Readd using namespace fmt
  * fix: prefix with `fmt::` to fix ambiguous call to `format()`, that also refers to `/usr/include/c++/13.1.1/format`
  * Debug times thousand separator
  * Debug times box changes
  * btop.cpp -> fmt
  * Fix link to themes folder
* Wed Apr 26 2023 scott.bradnick@suse.com
- Update to version 1.2.13+git20230318.872eb3e:
  * Silence "warning: unqualified call to 'std::move'" in clang.
  * Update everforest-dark-hard.theme
* Thu Feb 23 2023 scott.bradnick@suse.com
- Update to version 1.2.13+git20230223.471c68f:
  * readme: Add zfs_arc_cached documentation
  * Linux: subtract ZFS ARC min size from available memory
  * Replace -ftree-loop-vectorize with -ftree-vectorize.
  * Create adwaita.theme
  * fix zfs on freebsd not reporting IO
* Tue Jan  3 2023 scott.bradnick@suse.com
- Update to version 1.2.13+git20221215.c4ee41e:
  * Fixed: Makefile, VERBOSE flag now shows directory creation, Issue #480
  * Makefile: make build targets depend on directories
* Fri Dec  9 2022 scott.bradnick@suse.com
- Update to version 1.2.13+git20221130.e67a35d:
  * Removed unused statement...
  * Fixed: Use MemFree for used mem calculation if MemAvailable is greater than MemTotal.
* Mon Nov  7 2022 scott.bradnick@suse.com
- Update to version 1.2.13+git20221106.0f8498f:
  * v1.2.13 Bug fixes
  * osx: replace getnameinfo with inet_ntop
  * a comment about AF_LINK being ignored on purpose
  * FreeBSD: replace getnameinfo with inet_ntop
  * Fixed: Process nice value underflowing, issue #461
  * Add git config safe-directory inside freebsd vm
  * OSX: use the first IP of the interface
  * Added "Continuous Build FreeBSD" badge
  * Removed bad line and gcc12 install since gcc12 i preinstalled
  * Possible fix for broken xcode command line tools
  * Use gcc12 for macos12
  * FreeBSD: use the first IP of the interface
  * Use sh instead of csh
  * Update continuous-build-freebsd.yml
  * Update continuous-build-macos.yml
  * Create continuous-build-freebsd.yml
  * Add actions run for pull requests (macos) [skip actions]
  * Add actions run for pull requests (linux) [skip actions]
  * Fixed: Not picking up last username from /etc/passwd
  * make IPBUFFER_MAXSIZE an enum constant
  * use inet_ntop instead of getnameinfo
  * Show the first IP of the interface in NET box
  * Address comment
  * Fix bug in proc_tree view when showing full cmd
  * proc tree: fix width threshold to match commit message and use and/or instead of &&, ||
  * proc tree view: if there's more than 40 width left, try to print full cmd
  * macOS Ventura compile instructions
  * macOS Ventura compile instructions
  * Added autodetection for gcc12 to make compiling on macos Ventura easier.
  * Fixed: Moved up get_cpuHz() in the execution order to get better cpu clock reading.
  * Update continuous-build-macos.yml
  * Update continuous-build-macos.yml
  * Update continuous-build-linux.yml
  * Fixed: Ignore disks that fails in statvfs64() to avoid slowdowns and possible crashes.
  * fix: spelling mistake in btop.conf
  * Changed: Reverted back to sysconf(_SC_NPROCESSORS_ONLN) for Cpu core count ant let the new dynamic update fix if cores are turned on later
  * Makefile: Reverse VERBOSE bool to not stop with macOS make
  * Update README.md
  * Added more Makefile flags
  * Added: VERBOSE=true flag for Makefile to display all compiler commands and fixed so already set CXXFLAGS and LDFLAGS are displayed.
* Fri Oct  7 2022 scott.bradnick@suse.com
- Update to version 1.2.12+git20221007.3dd6a6c:
  * v1.2.12 Bug fix
  * Added: Dynamic updating of max number of CPU cores
* Fri Oct  7 2022 scott.bradnick@suse.com
- Update to version 1.2.11+git20221007.1444476:
  * v1.2.11 Quick fix for number of cores detection
  * Fixed: Number of cores wrongly detected for Ryzen in rare cases.
* Thu Oct  6 2022 Scott Bradnick <scott.bradnick@suse.com>
- Classic 'forgot to remove old .tar.gz before ci' scenario ...
* Thu Oct  6 2022 Scott Bradnick <scott.bradnick@suse.com>
- Classic 'forgot to add new .tar.gz before ci' scenario ...
* Thu Oct  6 2022 scott.bradnick@suse.com
- Update to version 1.2.10+git20221006.7a2556e:
  * v1.2.10 Bug fixes, cleanup + a new theme
  * Fixed: Cpu::collect() core count counter...
  * All but two places `const bool` have been updated
  * More const bool cleanup
  * Remove const from bool variables
  * Avoid the unnecessary use of copy constructor
  * Fix variable initialization to 'auto' for getB()
  * Forgot to update 'auto' usage wherever necessary
  * More 'No need for const & in bool'
  * No need for const & in bool
  * Changed: Using sysconf(_SC_NPROCESSORS_CONF) for number of cores instead of sysconf(_SC_NPROCESSORS_ONLN)
  * Further Cleanup Part 2
  * Further 'cleanup'
  * Further improvements
  * Clean up btop_tools.{hpp,cpp} files
  * Ignore files created by Qt Creator
* Sun Oct  2 2022 scott.bradnick@suse.com
- Update to version 1.2.9+git20221002.24f0609:
  * Fixed: Crashing when cores are offline
  * Fixed missing "#" from value
  * Fixed: Extra checks to avoid crash on trying to replace empty strings in tree mode
  * Updated README.md
  * [feature] Added Paper theme
  * Update FUNDING.yml
  * Update FUNDING.yml
  * Update README.md
* Sun Aug 28 2022 scott.bradnick@suse.com
- Update to version 1.2.9+git20220828.26ac007:
  * Fixed: Process tree filtering not case insensitive
  * v1.2.9 Bug fixes + new features and themes
  * Fixed: Memory values not clearing properly when not in graph mode in mem box
  * Cleaning up snap
  * Instructions for btop-desktop
  * Update snapcraft.yaml
  * Removing desktop launch
  * Add FreeBSD installation command
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update btop.desktop
  * Update btop.desktop
  * Add files via upload
  * Create btop.desktop
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Maybe
  * updated color change
  * Added: Option to hide the small cpu graphs for processes
  * Add Fedora/RHEL install docs
  * [fix] Color correction
  * Changed: Small graphs now show colors for each character
  * [feature] Created 'Elementarish' theme
  * Fixed: Getting selfpath on macos (fix for finding theme folder)
  * switch Logger calls to debug() to avoid filling up the logfile
  * rename zfs_pools_only option to zfs_hide_datasets, make its description clearer
  * check if at least one object was read before updating ZFS pool io in zfs_collect_pool_total_stats(), use try-catch to prevent possible crashes from int_64t conversions
  * add "?" to see help
  * Fixed: Logo transparency
  * Use fs::directory_iterator() instead of readdir() in ZFS functions, use fs::path instead of strings.
  * Move get_zfs_stat_file() and zfs_collect_pool_total_stats() functions declarations to btop_collect.cpp so they aren't included when compiling for macos and freebsd
  * Made ZFS stats collection compatible with zfs_pools_only option. ZFS pool's stat filepath points to the objset-* file when the option is disabled, otherwise it points to the pool's stats directory. Made ZFS total pool stat collection into a separate function for clean code. Also removed an unnecessary variable in the default ZFS stat collection, and changed io_ticks to track the number of reads/writes, reducing unnecessary calculations.
  * Re-implemented ZFS stat collection to be compatible with new ZFS versions, now it uses files "/proc/spl/kstat/zfs/*pool_name*/objset*". Needs additional work to be compatible with the option "zfs_pools_only".
  * Pass const string ref
  * Changed: Rewrite of process sorting and tree generation including fixes for tree sorting and mouse support
  * Add solarized_light theme
  * Add zfs_pools_only option
* Wed Jun 29 2022 scott.bradnick@suse.com
- Update to version 1.2.8+git20220629.102b6db:
  * v1.2.8 New features & themes
  * use Shared::procPath, fix Logger error type
  * Fixed kernel proc filter clearing issue + optimization
  * Optimize away clear_kernel_cache() function
  * Add tomorrow night theme
  * fix identation
  * Remove duplicate fstype setter
  * Remove forgotten debug logger calls
  * Added support for ZFS pool io stats monitoring
  * Changed: Disable battery monitoring if it fails instead of exiting
  * Add everforest-dark-hard.theme
  * Changed spaces to tabs
  * Finished kernel proc filtering.
  * Added a check for filter kernel mode
  * Added caching for kernel processes.
  * More indentation
  * Replaced my spaces with tabs
  * Indentation fix.
  * Woops that went unnoticed, didn't it?
  * Fixed menu description
  * Added linux label on the config option
  * Fixed clang-format off labels
  * Made kernel process filtering more efficient
  * Replaced $*\s with tabs
  * Fixed some formatting issues.
  * Added TUI option for kernel proc filtering.
  * Moved to correct version of the code
* Tue Jun 14 2022 scott.bradnick@suse.com
- Adjusting '/usr/bin' to '%%{_bindir}'
- Update to version 1.2.7+git20220603.83e9942:
  * Update README.md
  * Update btop.desktop
* Tue May 31 2022 Scott Bradnick <scott.bradnick@suse.com>
- Swapping out '%%{_datarootdir}' for '%%{_datadir}'.
* Tue May 31 2022 scott.bradnick@suse.com
- Update to version 1.2.7+git20220528.c3eb02f:
  * v1.2.7 Bug fixes & new features
  * Fixed: Net sync scale bug
  * Added tokyo-night & tokyo-storm theme
* Mon May 23 2022 scott.bradnick@suse.com
- Update to version 1.2.6+git20220516.c257938:
  * Fix makefile to install to /usr/local instead of /usr
  * Update makefile to install/remove icons and desktop entry
  * Add desktop icon svg and png
  * Add btop.desktop
  * Added: Case insensitive process filtering
* Thu May  5 2022 scott.bradnick@suse.com
- Update to version 1.2.6+git20220505.841941a:
  * Include ZFS ARC in cached/available memory on Linux
  * Fixed: Disk IO stats for individual partitions instead of whole disk
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * removed unneeded plugin
* Thu Apr 14 2022 scott.bradnick@suse.com
- Update to version 1.2.6+git20220414.9abf849:
  * Update snapcraft.yaml
* Wed Apr 13 2022 scott.bradnick@suse.com
- Update to version 1.2.6+git20220413.4bae3c4:
  * Update continuous-build-linux.yml
  * v1.2.6 Bug fixes
  * Changed: Enter symbol to a more common variant
  * updated robin_hood.h to v3.11.5
  * Fixed: Use cpu cores avarage temp if missing cpu package temp for FreeBSD
  * Fixed: Wrong memory unit when shorten and size is less than 10
* Mon Mar  7 2022 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.2.5:
  * Fixed: Fallback to less accurate UTF8 char count if conversion to
    wstring fails
  * Fixed: Small ui fixes for mem and disks
  * Added: New theme HotPurpleTrafficLight, by @pallebone
  * Fixed: title_left symbol between auto and zero in the net box is
    not displayed, by @mrdotx
  * Fixed: Mouse mappings for net box
* Mon Feb 28 2022 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.2.4:
  * Optimization: Proc::draw()
  * Fixed: Ignore duplicate disks with same mountpoint
  * Changed: Restrict command line for processes to 1000 characters to fix
    utf8 conversion errors
  * Added: add "g" and "G" to vim keys, by @mohi001
* Tue Feb 15 2022 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.2.3:
  * Changed: floating_humanizer() now show fractions when shortened and value
    is < 10
  * Fixed: Process tree not redrawing properly
  * Fixed: string to wstring conversion crash when string is too big
* Mon Feb 14 2022 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.2.2:
  * Changed: Reverted uncolor() back to using regex to fix delay in opening
    menu when compiled with musl
  * Added: Toggle for showing free disk space for privileged or normal users
  * Added: Clarification on signal screen that number can be manually entered
* Fri Feb 11 2022 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.2.1:
  * Added: Arrow only after use of "f" when filtering processes, by @NavigationHazard
  * Fixed: Fx::uncolor not removing all escapes
  * Fixed: Text alignment for popup boxes
  * Fixed: Terminal resize warning getting stuck
  * Removed: Unnecessary counter for atomic_lock
  * Added: Percentage progress to Makefile
  * Fixed: Alignment of columns in proc box when wide UTF8 characters are used
  * Fixed: Battery meter draw fix
* Tue Jan 18 2022 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.2.0:
  * Added: Support for FreeBSD, by @joske and @aristocratos
  * Fixed (again): Account for system rolling over net speeds in Net::collect()
  * Added: Theme gruvbox_material_dark, by @marcoradocchia
  * Added: Option for base 10 bytes/bits
* Wed Dec 29 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.1.4:
  * Fixed: Create dependency files in build directory when compiling, by @stwnt
  * Fixed: fix CPU temp fallback on macOS, by @joske
  * Changed: From rng::sort() to rng::stable_sort() for more stability
  * Fixed: in_avail() can always be zero, by @pg83
* Mon Dec 13 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.1.3:
  * Added: New theme ayu, by @AlphaNecron
  * Added: New theme gruvbox_dark_v2, by @pietryszak
  * Fixed: Macos cpu coretemp for Intel, by @joske
  * Added: New theme OneDark, by @vtmx
  * Fixed: Fixed network graph scale int rollover
  * Fixed: Suspected possibility of very rare stall in Input::clear()
* Sun Nov 28 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.1.2:
  * Fixed: SISEGV on macos Mojave, by @mgradowski
  * Fixed: Small optimizations and fixes to Mem::collect() and Input::get()
  * Fixed: Wrong unit for net_upload and net_download in config menu
  * Fixed: UTF-8 detection on macos
  * Fixed: coretemp iteration due to missing tempX_input, by @KFilipek
  * Fixed: coretemp ordering
* Tue Nov 16 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.1.1:
  * Added: Partial static build (libgcc, libstdc++) for macos
  * Changed: Continuous build macos switched to OSX 11.6 (Big Sur) and partial static build
  * Changed: Release binaries for macos switched to OSX 12 (Monterey) and partial static build
* Mon Nov 15 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.1.0:
  * Added: Support for OSX, by @joske and @aristocratos
* Tue Nov  9 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.0.24:
  * Changed: Collection ordering
  * Fixed: Restore all escape seq mouse modes on exit
  * Fixed: SIGINT not cleaning up on exit
- Update to upstream relaese 1.0.23:
  * Fixed: Config parser missing first value when not including version header
  * Fixed: Vim keys menu lists selection
  * Fixed: Stall when clearing input queue on exit and queue is >1
  * Fixed: Inconsistent behaviour of "q" key in the menus
* Thu Nov  4 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.0.22:
  * Fixed: Bad values for disks and network on 32-bit
* Tue Nov  2 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.0.21:
  * Fixed: Removed extra spaces in cpu name
  * Added: / as alternative bind for filter
  * Fixed: Security issue when running with SUID bit set
* Wed Oct 27 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.0.20:
  * Added: Improved cpu sensor detection for Ryzen Mobile, by @adnanpri
  * Changed: Updated makefile
  * Changed: Regex for Fx::uncolor() changed to string search and replace
  * Changed: Removed all use of regex with dedicated string functions
* Thu Oct 21 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.0.19:
  * Fixed: Makefile now tests compiler flag compatibility
* Tue Oct 19 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.0.18:
  * Fixed: Makefile g++ -dumpmachine failure to get platform on some distros
- Update to upstream release 1.0.17:
  * Changed: Reverted mutexes back to custom atomic bool based locks
  * Added: Static binaries switched to building with musl + more platforms, by @jan-guenter
  * Fixed: Improved battery detection, by @jan-guenter
  * Added: Displayed battery selectable in options menu
  * Fixed: Battery error if non existent battery named is entered
* Mon Oct 18 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.16 ...
* Wed Oct 13 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.15 ...
* Thu Oct  7 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.14 ...
* Sat Oct  2 2021 Stefan Seyfried <seife+obs@b1-systems.com>
- allow to build on 15.3 also
- improve filelist (no more "files listed twice...")
* Wed Sep 29 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.11 ...
* Tue Sep 28 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.10 ...
* Tue Sep 28 2021 Scott Bradnick <scott.bradnick@suse.com>
- Cleaning commented lines and changelog entries from spec file.
* Mon Sep 27 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.9 ...
* Fri Sep 24 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.6 ...
* Thu Sep 23 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.5 ...
* Wed Sep 22 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.4 ...
* Tue Sep 21 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.2 ...
* Mon Sep 20 2021 Scott Bradnick <scott.bradnick@suse.com>
- Initial commit for version 1.0.1 ...
